# Table of Contents

- [jira-service-management-integration](<./jira-service-management-integration.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Jira Service Management Integration](<./Jira-Service-Management-Integration.md>)
  - [Overview](<./Jira-Service-Management-Integration/Overview.md>)
  - [Benefits](<./Jira-Service-Management-Integration/Benefits.md>)
  - [Scope](<./Jira-Service-Management-Integration/Scope.md>)
  - [Limitations](<./Jira-Service-Management-Integration/Limitations.md>)
  - [Synchronizing Data](<./Jira-Service-Management-Integration/Synchronizing-Data.md>)
  - [Next Steps](<./Jira-Service-Management-Integration/Next-Steps.md>)
  - [Related Information](<./Jira-Service-Management-Integration/Related-Information.md>)
